NLSL: getdat.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
getdat.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
integer function | getdat (filen, infmt, modebc, nspln, ideriv, norm, lumsg, comment, ncmts, spndat, bi, delb, stddev, xraw, yraw, y2)
integer function | getasc (filen, x, y, n, comment, ncmt, maxcmt, maxinp)
double precision function | sglint (arry, n)
double precision function | dblint (arry, n)
subroutine | linebc (x, y, n, modebc, c0, c1, stddev)
subroutine | ncspln (x, y, n, y2)
subroutine | splnay (xa, ya, y2a, n, x0, dx, y, ns)
subroutine | normlz (arry, n, dx, ideriv, lumsg, anorm)

## Function/Subroutine Documentation

double precision function dblint | ( | double precision, dimension(n) | arry,
|  | integer | n
| ) |  |

Definition at line 337 of file getdat.f90.

integer function getasc | ( | character*30 | filen,
|  | double precision, dimension(*) | x,
|  | double precision, dimension(*) | y,
|  | integer | n,
|  | character*80, dimension(maxcmt) | comment,
|  | integer | ncmt,
|  | integer | maxcmt,
|  | integer | maxinp
| ) |  |

Definition at line 221 of file getdat.f90.

Here is the call graph for this function:

integer function getdat | ( | character*30 | filen,
|  | integer | infmt,
|  | integer | modebc,
|  | integer | nspln,
|  | integer | ideriv,
|  | integer | norm,
|  | integer | lumsg,
|  | character*80, dimension(mxcmt) | comment,
|  | integer | ncmts,
|  | double precision, dimension(nspln) | spndat,
|  | double precision | bi,
|  | double precision | delb,
|  | double precision | stddev,
|  | double precision, dimension(mxinp) | xraw,
|  | double precision, dimension(mxinp) | yraw,
|  | double precision, dimension(mxinp) | y2
| ) |  |

Definition at line 64 of file getdat.f90.

Here is the call graph for this function:

subroutine linebc | ( | double precision, dimension(n) | x,
|  | double precision, dimension(n) | y,
|  | integer | n,
|  | integer | modebc,
|  | double precision | c0,
|  | double precision | c1,
|  | double precision | stddev
| ) |  |

Definition at line 377 of file getdat.f90.

Here is the caller graph for this function:

subroutine ncspln | ( | double precision, dimension(n) | x,
|  | double precision, dimension(n) | y,
|  | integer | n,
|  | double precision, dimension(n) | y2
| ) |  |

Definition at line 446 of file getdat.f90.

Here is the caller graph for this function:

subroutine normlz | ( | double precision, dimension(n) | arry,
|  | integer | n,
|  | double precision | dx,
|  | integer | ideriv,
|  | integer | lumsg,
|  | double precision | anorm
| ) |  |

Definition at line 545 of file getdat.f90.

Here is the caller graph for this function:

double precision function sglint | ( | double precision, dimension(n) | arry,
|  | integer | n
| ) |  |

Definition at line 314 of file getdat.f90.

subroutine splnay | ( | double precision, dimension(n) | xa,
|  | double precision, dimension(n) | ya,
|  | double precision, dimension(n) | y2a,
|  | integer | n,
|  | double precision | x0,
|  | double precision | dx,
|  | double precision, dimension(ns) | y,
|  | integer | ns
| ) |  |

Definition at line 488 of file getdat.f90.

Here is the caller graph for this function: